# xslearn

xslearn is a machine learning toolkit implemented by Python. (keep updating...)

## model examples(below are implemented models)

**- linear_model**

* [Perceptron](https://github.com/eLeVeNnN/xslearn/blob/master/examples/Perceptron.md)
* [Logistic Regression](https://github.com/eLeVeNnN/xslearn/blob/master/examples/logistics%20regression.md)



**- neighbors**

+ [KNeighborsClassifier](https://github.com/eLeVeNnN/xslearn/blob/master/examples/KNeighborsClassifier.md)



**- naive_bayes**

+ [NaiveBayes](https://github.com/eLeVeNnN/xslearn/blob/master/examples/NaiveBayes.md)

+ [GaussianNaiveBayes](https://github.com/eLeVeNnN/xslearn/blob/master/examples/NaiveBayes.md)

  

**- svm**

+ [SVC](https://github.com/eLeVeNnN/xslearn/blob/master/examples/Support%20vector%20machine.md)



**- tree**

+ [DecisionTreeClassifier](https://github.com/eLeVeNnN/xslearn/blob/master/examples/DecisionTreeClassifier.md)
  + ID3
  + C4.5
  + Cart
+ DecisionTreeRegressor



**- ensemble**

+ [Boosting]()

  + AdaboostClassifier

+ Bagging

  + BaggingClassifier
  + BaggingRegressor
  + [RandomForestClassifier](https://github.com/eLeVeNnN/xslearn/blob/master/examples/RandomForestClassifier.md)
  + RandomForestRegressor

  